==> oricli-0.1.20.tgz: package/commands/add.js <==
var uuid=require('uuid')
var extract = require('extract-zip')
var fs = require('fs');
//var origami =require('origamicore')
const program = require('commander');  
const { prompt } = require('inquirer'); 
const { exec,spawn  } = require('child_process');
var scan = require('../scan');
var http = require('http');
var chokidar = require('chokidar');
var esprima = require('esprima');
var escodegen = require('escodegen');


module.exports = class add{
  constructor()
  {
    this.create()
  }
  async create()
  {
    //process.stdout.write('\033c');
    console.log('1->Express Endpoint')
    console.log('2->Socket Endpoint')
    console.log('3->Service')
    console.log('4->Module')
    console.log('5->Session Manager')
    console.log('6->Storage')
    console.log('7->UI')
    console.log('8->Database')
    var index = await global.read('enter number of item  : ')
    if(index.value==1)
    {
      try{this.createExpress()}catch(exp){console.log(exp)}
       
    }
    if(index.value==2)
    {
      try{this.createSocket()}catch(exp){console.log(exp)}
      
    }
    if(index.value==3)
    {
      try{this.createService()}catch(exp){console.log(exp)}
      
    }
    if(index.value==4)
    {
      try{this.createModule()}catch(exp){console.log(exp)}
      
    }
    if(index.value==8)
    {
      try{ this.createDatabase()}catch(exp){console.log(exp)}
     
    }
  }
  async findParsedElement(name)
  {
      var model = esprima.parseScript(fs.readFileSync('./config.js')+'') 
      for(var a of model.body)
      {
           
          if(
              a.type=="ExpressionStatement"&& 
              a.expression && 
              a.expression.type=="AssignmentExpression" &&
              a.expression.operator=="=" &&
              a.expression.left  &&
              a.expression.left.type=="MemberExpression" &&
              a.expression.left.object &&
              a.expression.left.object.name=="module" &&  
              a.expression.left.property &&
              a.expression.left.property.name=="exports" 
          )
          {
              var el=a.expression.right.elements
              for(var b of el)
              {
                  for(var c of b.properties)
                  {
                      //if((c.key.value=="name" || c.key.name=="name"))
                      //    console.log('--->',c.value)
                      if((c.key.value=="name" || c.key.name=="name") && c.value.value==name)
                      {
                          return {model:model,config:a.expression.right,element:b}
  
                      }
                  }
              }
                return {model:model,config:a.expression.right}
          }
      }
      return null
  }
  async createExpress () 
  {
      let port = await global.readInt('enter port number (1-60000)  : ',1,60000)
      let type = await global.choseItem('type (http or https):',['http','https'])
      //var config = findByName('endpoint')
      let x= {
          id:uuid.v4(),
          name:'endpoint',
          express:[{
              'public':'/{path of folder}',
              CrossDomain:'{domains or *}',
              bodyLimit: '{max size of body }',
              urlLimit:'{max url size}',
              authz:{domain:'staticAuthz'}, 
              sessionManager:{
                  type:'redis',
                  expire:1000*60*60*24*60,
                  connection:{
                      host:'localhost',
                      port:6379
                  }
              }
          }],
      }
      x.express[0][type]={port:port}
      var el=await this.findParsedElement("endpoint")
      if(!el)
      {
          console.log(consoleColor.red,'config file is not standard ')
          return 
      } 
      if(el.element)
      {
          var sync = esprima.parseScript('var x= '+JSON.stringify(x.express[0]));
          var addelement= sync.body[0].declarations[0].init
          var find=false
          for(var dx of el.element.properties)
          {
              //console.log()
              if(dx.key.value=='express' || dx.key.name=='express')
              {
                  dx.value.elements.push(addelement)
                  find=true
              }
          }
  
          
          if(!find)
          {
              // sync = esprima.parseScript('var x= '+JSON.stringify(x.express));
              // addelement= sync.body[0].declarations[0].init
              // el.element.properties.push(addelement)
  
  
  
              
              sync = esprima.parseScript('var x= '+JSON.stringify(x.express)); 
              addelement= sync.body[0].declarations[0].init
              el.element.properties.push(
                  {
                      "type": "Property",
                      "key": {
                        "type": "Identifier",
                        "name": "express"
                      },
                      "computed": false,
                      "value": addelement,
                      "kind": "init",
                      "method": false,
                      "shorthand": false
                    }
                  
                  )
          }
      }
      else
      { 
          var sync = esprima.parseScript('var x= '+JSON.stringify(x));
          var addelement= sync.body[0].declarations[0].init
          //console.log(sync.body[0].declarations[0].init) 
         // console.log('-->', el)
          el.config.elements.push(addelement) 
          
      }
      escodegen.generate(el.model) 
      fs.writeFileSync('./config.js',escodegen.generate(el.model))
  
      
       
  }
  
  findByName(name){ 
    var config = loadConfig()
    for(var a of config)
    {
        if(a.name==name)
        { 
            return a
        }
    }
    return null
  }  
  async createService(){
      let name = await global.readString('enter service name :' )
      let x={
          id: uuid.v4(),
          name: 'service',
          context: '{databse connection name }',
          domain: name,
          driver:  '{pathLocation}',
          structure:  '{structLocation}',
          funcs: [{
                  name: 'test',
                  title: 'test'
              }],
          auth: ['test']
      }
      var strx='var x = '+ JSON.stringify(x)
                              .replace('"{pathLocation}"','global.path + "/services/'+name+'/index.js"')
                              .replace('"{structLocation}"','global.path + "/services/'+name+'/struct.js"')
      if(!fs.existsSync('./services'))
          fs.mkdirSync('./services')
      if(fs.existsSync('./services/'+name))
      {
          console.log(consoleColor.red,'folder "/services/'+name+'/" is exist')
          return
      }
      fs.mkdirSync('./services/'+name)
      var tmpindex='module.exports = class '+name+'service\r\n'+
                   '{\r\n'+
                   '    constructor(config,dist)\r\n'+
                   '    { \r\n'+
                   '        this.statics=config.statics\r\n'+
                   '        this.context=config.context\r\n'+
                   '    }\r\n'+
                   '    async test(msg,func,self)\r\n'+
                   '    { \r\n'+
                   '        return func(null,{m:"hello."})\r\n'+
                   '    }\r\n'+
                   '}\r\n'
      var tmpstruct='module.exports = {\r\n'+
                   '    sampleInterface:{\r\n'+
                   '        struct:{\r\n'+
                   '            test1:{type:"number"},\r\n'+ 
                   '            test2:{type:"string"},\r\n'+ 
                   '            test1:{type:"boolean",nullable:true},\r\n'+ 
                   '        }\r\n'+
                   '    }\r\n'+
                   '}\r\n'
      fs.writeFileSync('./services/'+name+'/index.js',tmpindex)
      fs.writeFileSync('./services/'+name+'/struct.js',tmpstruct)
      var el=await  this.findParsedElement("sssssss")
      if(!el)
      {
          console.log(consoleColor.red,'config file is not standard ')
          return 
      } 
      var sync = esprima.parseScript(strx);
      var addelement= sync.body[0].declarations[0].init 
      el.config.elements.push(addelement)
      escodegen.generate(el.model) 
      fs.writeFileSync('./config.js',escodegen.generate(el.model))
  }
  async createDatabase(){
      let name = await global.readString('enter name :' )
      let type = await global.choseItem('type (mongodb or mysql):',['mongodb','mysql']) 
      let host = await global.readString('enter host (ex : localhost or 127.0.0.1 ...):' )
      let username = await global.readString('enter username :' )
      let password = await global.readString('enter password :' )
      let database = await global.readString('enter database :' )
      var x={
              id: uuid.v4(),
              name: 'database',
              connection: [{
                      name: name,
                      type: type,
                      host: host,
                      username: username,
                      password: password,
                      database: database
                  }]
          } 
      var el=await  this.findParsedElement("database")
      if(!el)
      {
          console.log(consoleColor.red,'config file is not standard ')
          return 
      } 
      if(el.element)
      {
          var sync = esprima.parseScript('var x= '+JSON.stringify(x.connection[0]));
          var addelement= sync.body[0].declarations[0].init
          var find=false
          for(var dx of el.element.properties)
          {
              //console.log()
              if(dx.key.value=='connection' || dx.key.name=='connection')
              {
                  dx.value.elements.push(addelement)
                  find=true
              }
          }
          if(!find)
          {
              sync = esprima.parseScript('var x= '+JSON.stringify(x.connection)); 
              addelement= sync.body[0].declarations[0].init
              el.element.properties.push(
                  {
                      "type": "Property",
                      "key": {
                        "type": "Identifier",
                        "name": "connection"
                      },
                      "computed": false,
                      "value": addelement,
                      "kind": "init",
                      "method": false,
                      "shorthand": false
                    }
                  
                  )
          }
      }
      else
      { 
          var sync = esprima.parseScript('var x= '+JSON.stringify(x));
          var addelement= sync.body[0].declarations[0].init 
          el.config.elements.push(addelement) 
          
      }
      escodegen.generate(el.model) 
      fs.writeFileSync('./config.js',escodegen.generate(el.model))
  
  }
  async createModule(){
      let name = await global.readString('enter module name :' )    
      if(!fs.existsSync('./origami-modules'))
      {
          fs.mkdirSync('./origami-modules')
      }
      var m=await global.installPackage(name)
  
      if(!m)
          return
      if(!fs.existsSync('./origami-modules/'+name+'/config.js'))
      {
          return
      }    
      var config= eval( fs.readFileSync('./origami-modules/'+name+'/config.js')+'')
      //    console.log(config)
      var c=new  config()   
      var obj={}
      if(c.getDefaultConfig)
      {
        obj=c.getDefaultConfig()
          //console.log(c.getDefaultConfig())
      }
      let x= {
          id:uuid.v4(),
          name:'module',
          type:name,
          config:obj
      } 
      var el=await  this.findParsedElement("endpoint")
      if(!el)
      {
          console.log(consoleColor.red,'config file is not standard ')
          return 
      } 
      var sync = esprima.parseScript('var x= '+JSON.stringify(x));
      var addelement= sync.body[0].declarations[0].init 
      el.config.elements.push(addelement) 
      escodegen.generate(el.model) 
      fs.writeFileSync('./config.js',escodegen.generate(el.model))
  }
  async createSocket ()
  {
      let port = await global.readInt('enter port number (1-60000)  : ',1,60000)
      let type = await global.choseItem('type (http or https):',['http','https'])
      //var config = findByName('endpoint')
      let x= {
          id:uuid.v4(),
          name:'endpoint',
          socket:[
              {
                  sessionContext:'redis',
                  mode:type,
                  port:port,
                  protocol:'echo-protocol',
                  publication:{
                      id:'111111'
                  }
              }
          ], 
      } 
      var el=await  this.findParsedElement("endpoint")
      if(!el)
      {
          console.log(consoleColor.red,'config file is not standard ')
          return 
      } 
      if(el.element)
      {
          var sync = esprima.parseScript('var x= '+JSON.stringify(x.socket[0]));
          var addelement= sync.body[0].declarations[0].init
          var find=false
          for(var dx of el.element.properties)
          {
              //console.log()
              if(dx.key.value=='socket' || dx.key.name=='socket')
              {
                  dx.value.elements.push(addelement)
                  find=true
              }
          }
          if(!find)
          {
              sync = esprima.parseScript('var x= '+JSON.stringify(x.socket));
              //console.log(sync.body[0].declarations[0])
              addelement= sync.body[0].declarations[0].init
              el.element.properties.push(
                  {
                      "type": "Property",
                      "key": {
                        "type": "Identifier",
                        "name": "socket"
                      },
                      "computed": false,
                      "value": addelement,
                      "kind": "init",
                      "method": false,
                      "shorthand": false
                    }
                  
                  )
          }
      }
      else
      { 
          var sync = esprima.parseScript('var x= '+JSON.stringify(x));
          var addelement= sync.body[0].declarations[0].init 
          el.config.elements.push(addelement) 
          
      }
      escodegen.generate(el.model) 
      fs.writeFileSync('./config.js',escodegen.generate(el.model))
  
      
       
  }
}

==> oricli-1.0.0.tgz: package/commands/add.js <==
var uuid=require('uuid')
var extract = require('extract-zip')
var fs = require('fs');
//var origami =require('origamicore')
const program = require('commander');  
const { prompt } = require('inquirer'); 
const { exec,spawn  } = require('child_process');
var scan = require('../scan');
var http = require('http');
var chokidar = require('chokidar');
var esprima = require('esprima');
var escodegen = require('escodegen');
var installer =require('./install.js')

module.exports = class add{
  constructor()
  {
    this.create()
  }
  async create()
  {
    //process.stdout.write('\033c');
   // console.log('1->Express Endpoint')
   // console.log('2->Socket Endpoint')
    console.log('1->Service')
    console.log('2->Module')
   // console.log('5->Session Manager')
   // console.log('6->Storage')
   // console.log('7->UI')
   // console.log('8->Database')
    var index = await global.read('enter number of item  : ')
    // if(index.value==1)
    // {
      // try{this.createExpress()}catch(exp){console.log(exp)}
       
    // }
    // if(index.value==2)
    // {
      // try{this.createSocket()}catch(exp){console.log(exp)}
      
    // }
    if(index.value==1)
    {
      try{this.createService()}catch(exp){console.log(exp)}
      
    }
    if(index.value==2)
    {
      try{this.createModule()}catch(exp){console.log(exp)}
      
    }
    // if(index.value==8)
    // {
      // try{ this.createDatabase()}catch(exp){console.log(exp)}
     
    // }
  }
  async findParsedElement(name)
  {
      var model = esprima.parseScript(fs.readFileSync('./config.js')+'') 
      for(var a of model.body)
      {
           
          if(
              a.type=="ExpressionStatement"&& 
              a.expression && 
              a.expression.type=="AssignmentExpression" &&
              a.expression.operator=="=" &&
              a.expression.left  &&
              a.expression.left.type=="MemberExpression" &&
              a.expression.left.object &&
              a.expression.left.object.name=="module" &&  
              a.expression.left.property &&
              a.expression.left.property.name=="exports" 
          )
          {
              var el=a.expression.right.elements
			  //console.log('--dd--->',el)
              for(var b of el)
              {
                  for(var c of b.properties)
                  {
                      //if((c.key.value=="name" || c.key.name=="name"))
                      //    console.log('--->',c.value)
                      if((c.key.value=="name" || c.key.name=="name") && c.value.value==name)
                      {
                          return {model:model,config:a.expression.right,element:b}
  
                      }
                  }
              }
                return {model:model,config:a.expression.right}
          }
      }
      return null
  }
  async createExpress () 
  {
      let port = await global.readInt('enter port number (1-60000)  : ',1,60000)
      let type = await global.choseItem('type (http or https):',['http','https'])
      //var config = findByName('endpoint')
      let x= {
          id:uuid.v4(),
          name:'endpoint',
          express:[{
              'public':'/{path of folder}',
              CrossDomain:'{domains or *}',
              bodyLimit: '{max size of body }',
              urlLimit:'{max url size}',
              authz:{domain:'staticAuthz'}, 
              sessionManager:{
                  type:'redis',
                  expire:1000*60*60*24*60,
                  connection:{
                      host:'localhost',
                      port:6379
                  }
              }
          }],
      }
      x.express[0][type]={port:port}
      var el=await this.findParsedElement("endpoint")
      if(!el)
      {
          console.log(consoleColor.red,'config file is not standard ')
          return 
      } 
      if(el.element)
      {
          var sync = esprima.parseScript('var x= '+JSON.stringify(x.express[0]));
          var addelement= sync.body[0].declarations[0].init
          var find=false
          for(var dx of el.element.properties)
          {
              //console.log()
              if(dx.key.value=='express' || dx.key.name=='express')
              {
                  dx.value.elements.push(addelement)
                  find=true
              }
          }
  
          
          if(!find)
          {
              // sync = esprima.parseScript('var x= '+JSON.stringify(x.express));
              // addelement= sync.body[0].declarations[0].init
              // el.element.properties.push(addelement)
  
  
  
              
              sync = esprima.parseScript('var x= '+JSON.stringify(x.express)); 
              addelement= sync.body[0].declarations[0].init
              el.element.properties.push(
                  {
                      "type": "Property",
                      "key": {
                        "type": "Identifier",
                        "name": "express"
                      },
                      "computed": false,
                      "value": addelement,
                      "kind": "init",
                      "method": false,
                      "shorthand": false
                    }
                  
                  )
          }
      }
      else
      { 
          var sync = esprima.parseScript('var x= '+JSON.stringify(x));
          var addelement= sync.body[0].declarations[0].init
          //console.log(sync.body[0].declarations[0].init) 
         // console.log('-->', el)
          el.config.elements.push(addelement) 
          
      }
      escodegen.generate(el.model) 
      fs.writeFileSync('./config.js',escodegen.generate(el.model))
  
      
       
  }
  
  findByName(name){ 
    var config = loadConfig()
    for(var a of config)
    {
        if(a.name==name)
        { 
            return a
        }
    }
    return null
  }  
  async createService(){
      let name = await global.readString('enter service name :' )
      let x={
          id: uuid.v4(),
          name: 'service',
          context: '{databse connection name }',
          domain: name,
          driver:  '{pathLocation}',
          structure:  '{structLocation}',
          funcs: [{
                  name: 'test',
                  title: 'test'
              }],
          auth: ['test']
      }
      var strx='var x = '+ JSON.stringify(x)
                              .replace('"{pathLocation}"','global.path + "/services/'+name+'/index.js"')
                              .replace('"{structLocation}"','global.path + "/services/'+name+'/struct.js"')
      if(!fs.existsSync('./services'))
          fs.mkdirSync('./services')
      if(fs.existsSync('./services/'+name))
      {
          console.log(consoleColor.red,'folder "/services/'+name+'/" is exist')
          return
      }
      fs.mkdirSync('./services/'+name)
      var tmpindex='module.exports = class '+name+'service\r\n'+
                   '{\r\n'+
                   '    constructor(config,dist)\r\n'+
                   '    { \r\n'+
                   '        this.statics=config.statics\r\n'+
                   '        this.context=config.context\r\n'+
                   '    }\r\n'+
                   '    async test(msg,func,self)\r\n'+
                   '    { \r\n'+
                   '        return func(null,{m:"hello."})\r\n'+
                   '    }\r\n'+
                   '}\r\n'
      var tmpstruct='module.exports = {\r\n'+
                   '    sampleInterface:{\r\n'+
                   '        struct:{\r\n'+
                   '            test1:{type:"number"},\r\n'+ 
                   '            test2:{type:"string"},\r\n'+ 
                   '            test1:{type:"boolean",nullable:true},\r\n'+ 
                   '        }\r\n'+
                   '    }\r\n'+
                   '}\r\n'
      fs.writeFileSync('./services/'+name+'/index.js',tmpindex)
      fs.writeFileSync('./services/'+name+'/struct.js',tmpstruct)
      var el=await  this.findParsedElement("sssssss")
      if(!el)
      {
          console.log(consoleColor.red,'config file is not standard ')
          return 
      } 
      var sync = esprima.parseScript(strx);
      var addelement= sync.body[0].declarations[0].init 
      el.config.elements.push(addelement)
      escodegen.generate(el.model) 
      fs.writeFileSync('./config.js',escodegen.generate(el.model))
  }
  async createDatabase(){
      let name = await global.readString('enter name :' )
      let type = await global.choseItem('type (mongodb or mysql):',['mongodb','mysql']) 
      let host = await global.readString('enter host (ex : localhost or 127.0.0.1 ...):' )
      let username = await global.readString('enter username :' )
      let password = await global.readString('enter password :' )
      let database = await global.readString('enter database :' )
      var x={
              id: uuid.v4(),
              name: 'database',
              connection: [{
                      name: name,
                      type: type,
                      host: host,
                      username: username,
                      password: password,
                      database: database
                  }]
          } 
      var el=await  this.findParsedElement("database")
      if(!el)
      {
          console.log(consoleColor.red,'config file is not standard ')
          return 
      } 
      if(el.element)
      {
          var sync = esprima.parseScript('var x= '+JSON.stringify(x.connection[0]));
          var addelement= sync.body[0].declarations[0].init
          var find=false
          for(var dx of el.element.properties)
          {
              //console.log()
              if(dx.key.value=='connection' || dx.key.name=='connection')
              {
                  dx.value.elements.push(addelement)
                  find=true
              }
          }
          if(!find)
          {
              sync = esprima.parseScript('var x= '+JSON.stringify(x.connection)); 
              addelement= sync.body[0].declarations[0].init
              el.element.properties.push(
                  {
                      "type": "Property",
                      "key": {
                        "type": "Identifier",
                        "name": "connection"
                      },
                      "computed": false,
                      "value": addelement,
                      "kind": "init",
                      "method": false,
                      "shorthand": false
                    }
                  
                  )
          }
      }
      else
      { 
          var sync = esprima.parseScript('var x= '+JSON.stringify(x));
          var addelement= sync.body[0].declarations[0].init 
          el.config.elements.push(addelement) 
          
      }
      escodegen.generate(el.model) 
      fs.writeFileSync('./config.js',escodegen.generate(el.model))
  
  }
  async createModule(){
      let name = await global.readString('enter module name :' )
      let isNpm =await global.choseItem('run as Npm :(yes/no)' ,['yes','no'])
         await installer.install('origamicore');
      if(isNpm=='yes')
      {
         await installer.install('ori'+name);
         // var config=require('ori'+name+'/config.js')
         var config=await global.runCommand(`node -e "console.log (JSON.stringify( new (require('ori${name}/config.js'))().getDefaultConfig()))"`)
         console.log('->',config)
		 let x= { 
			id:uuid.v4(),
			name: 'module',
			type:name,
			isNpm:true,
			config:JSON.parse(config)
		 }
		 
		  var el=await this.findParsedElement("endpoint")
		  if(!el)
		  {
			  console.log(consoleColor.red,'config file is not standard ')
			  return 
		  } 
          var sync = esprima.parseScript('var x= '+JSON.stringify(x));
          var addelement= sync.body[0].declarations[0].init 
          el.config.elements.push(addelement) 
          escodegen.generate(el.model) 
          fs.writeFileSync('./config.js',escodegen.generate(el.model))
      }
      else
      {
          
          if(!fs.existsSync('./origami-modules'))
          {
              fs.mkdirSync('./origami-modules')
          }
          var m=await global.installPackage(name)
      
          if(!m)
              return
          if(!fs.existsSync('./origami-modules/'+name+'/config.js'))
          {
              return
          }    
          var config= eval( fs.readFileSync('./origami-modules/'+name+'/config.js')+'')
          //    console.log(config)
          var c=new  config()   
          var obj={}
          if(c.getDefaultConfig)
          {
            obj=c.getDefaultConfig()
              //console.log(c.getDefaultConfig())
          }
          let x= {
              id:uuid.v4(),
              name:'module',
              type:name,
              config:obj
          } 
          var el=await  this.findParsedElement("endpoint")
          if(!el)
          {
              console.log(consoleColor.red,'config file is not standard ')
              return 
          } 
          var sync = esprima.parseScript('var x= '+JSON.stringify(x));
          var addelement= sync.body[0].declarations[0].init 
          el.config.elements.push(addelement) 
          escodegen.generate(el.model) 
          fs.writeFileSync('./config.js',escodegen.generate(el.model))
      }
  }
  async createSocket ()
  {
      let port = await global.readInt('enter port number (1-60000)  : ',1,60000)
      let type = await global.choseItem('type (http or https):',['http','https'])
      //var config = findByName('endpoint')
      let x= {
          id:uuid.v4(),
          name:'endpoint',
          socket:[
              {
                  sessionContext:'redis',
                  mode:type,
                  port:port,
                  protocol:'echo-protocol',
                  publication:{
                      id:'111111'
                  }
              }
          ], 
      } 
      var el=await  this.findParsedElement("endpoint")
      if(!el)
      {
          console.log(consoleColor.red,'config file is not standard ')
          return 
      } 
      if(el.element)
      {
          var sync = esprima.parseScript('var x= '+JSON.stringify(x.socket[0]));
          var addelement= sync.body[0].declarations[0].init
          var find=false
          for(var dx of el.element.properties)
          {
              //console.log()
              if(dx.key.value=='socket' || dx.key.name=='socket')
              {
                  dx.value.elements.push(addelement)
                  find=true
              }
          }
          if(!find)
          {
              sync = esprima.parseScript('var x= '+JSON.stringify(x.socket));
              //console.log(sync.body[0].declarations[0])
              addelement= sync.body[0].declarations[0].init
              el.element.properties.push(
                  {
                      "type": "Property",
                      "key": {
                        "type": "Identifier",
                        "name": "socket"
                      },
                      "computed": false,
                      "value": addelement,
                      "kind": "init",
                      "method": false,
                      "shorthand": false
                    }
                  
                  )
          }
      }
      else
      { 
          var sync = esprima.parseScript('var x= '+JSON.stringify(x));
          var addelement= sync.body[0].declarations[0].init 
          el.config.elements.push(addelement) 
          
      }
      escodegen.generate(el.model) 
      fs.writeFileSync('./config.js',escodegen.generate(el.model))
  
      
       
  }
}
